package com.gic.auth.dao.mapper;

import com.gic.auth.dto.UserListDTO;
import com.gic.auth.entity.TabSysUser;
import com.gic.auth.qo.UserListQO;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 
 * @ClassName: TabSysUserMapper
 * @Description:  
 * @author zhiwj
 * @date 2020-09-10 9:42
 */
public interface TabSysUserMapper {
    /**
     * 根据主键删除
     *
     * @param userId 主键
     * @return 更新条目数
     */
    int deleteByPrimaryKey(Integer userId);

    /**
     * 插入一条记录
     *
     * @param record 实体对象
     * @return 更新条目数
     */
    int insert(TabSysUser record);

    /**
     * 动态插入一条记录
     *
     * @param record 实体对象
     * @return 更新条目数
     */
    int insertSelective(TabSysUser record);

    /**
     * 根据主键查询
     *
     * @param userId 主键
     * @return 实体对象
     */
    TabSysUser selectByPrimaryKey(Integer userId);

    /**
     * 根据主键动态更新记录
     *
     * @param record 实体对象
     * @return 更新条目数
     */
    int updateByPrimaryKeySelective(TabSysUser record);

    /**
     * 根据主键更新记录
     *
     * @param record 实体对象
     * @return 更新条目数
     */
    int updateByPrimaryKey(TabSysUser record);

    /**
     * 手机号码查询个数
     * @param phone
     * @param userId
     * @param enterpriseId
     * @return
     */
    int countByPhone(@Param("phone") String phone, @Param("userId") Integer userId,
            @Param("enterpriseId") Integer enterpriseId);

    /**
     * 手机号码查询个数
     * @Title: countByPhoneAndLoginType 
     * @Description:
      * @author guojuxing
     * @param phone
     * @param userId
     * @param enterpriseId 
     * @param loginType
     * @return  int 
      */
    int countByPhoneAndLoginType(@Param("phone") String phone, @Param("userId") Integer userId,
            @Param("enterpriseId") Integer enterpriseId, @Param("loginType") Integer loginType);

    /**
     * selectByEnterpriseId
     * @Title: selectByEnterpriseId
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @return com.gic.auth.entity.TabSysUser
     * @throws
     */
    TabSysUser selectByEnterpriseId(@Param("enterpriseId") Integer enterpriseId);

    /**
     * listUserByPhoneNumberAndEnterprise
     * @Title: listUserByPhoneNumberAndEnterprise
     * @Description:
     * @author zhiwj
     * @param phoneNumber
     * @param nationCode
     * @param enterpriseId
     * @return java.util.List<com.gic.auth.entity.TabSysUser>
     * @throws
     */
    List<TabSysUser> listUserByPhoneNumberAndEnterprise(@Param("phoneNumber") String phoneNumber,
            @Param("nationCode") String nationCode, @Param("enterpriseId") Integer enterpriseId);

    /**
     * login
     * @Title: login
     * @Description:
     * @author zhiwj
     * @param nationCode
     * @param phoneNumber
     * @param password
     * @param enterpriseId
     * @return com.gic.auth.entity.TabSysUser
     * @throws
     */
    TabSysUser login(@Param("nationCode") String nationCode, @Param("phoneNumber") String phoneNumber,
            @Param("password") String password, @Param("enterpriseId") Integer enterpriseId);

    /**
     * 列表查询
     * @Title: listUser 
     * @Description:
      * @author guojuxing
     * @param params 
     * @return  java.util.List<com.gic.auth.entity.TabSysUser> 
      */
    List<UserListDTO> listUser(UserListQO params);

    /**
     * 逻辑删除
     * @Title: deleteById 
     * @Description:
      * @author guojuxing
     * @param userId 
     * @return  int 
      */
    int deleteById(@Param("userId") Integer userId);

    /**
     * getFirstNotInUserId
     * @Title: getFirstNotInUserId
     * @Description:
     * @author zhiwj
     * @param enterpriseId
     * @param userIdList
     * @return java.lang.Integer
     * @throws
     */
    Integer getFirstNotInUserId(@Param("enterpriseId") Integer enterpriseId, @Param("ids") List<Integer> userIdList);

    /**
     * countUserByUserIds
     * @Title: countUserByUserIds
     * @Description:
     * @author zhiwj
     * @param userIdList
     * @return java.lang.Integer
     * @throws
     */
    Integer countUserByUserIds(@Param("ids") List<Integer> userIdList);

    /**
     * listUserByIdList
     * @Title: listUserByIdList
     * @Description:
     * @author zhiwj
     * @param userIdList
     * @return java.util.List<com.gic.auth.entity.TabSysUser>
     * @throws
     */
    List<TabSysUser> listUserByIdList(@Param("ids") List<Integer> userIdList);

    /**
     * 查询不在范围内的用户
     * @Title: listUserNotInIdList 
     * @Description:
      * @author guojuxing
     * @param userIdList 
     * @param search
     * @param enterpriseId 
     * @return  java.util.List<com.gic.auth.entity.TabSysUser> 
      */
    List<TabSysUser> listUserNotInIdList(@Param("ids") List<Integer> userIdList, @Param("search") String search,
            @Param("enterpriseId") Integer enterpriseId);

    /**
     * 查询所有的用户，gic管理员/运营实施管理员
     * @Title: listAllUser 
     * @Description:
      * @author guojuxing
     * @param enterpriseId 
     * @return  java.util.List<java.lang.Integer> 
      */
    List<Integer> listAllUser(@Param("enterpriseId") Integer enterpriseId);

    /**
     * listGicUser 
     * @Title: listGicUser
     * @Description: 
     * @author zhiwj 
     * @param enterpriseId
     * @param isGic
     * @return java.util.List<com.gic.auth.entity.TabSysUser>
     * @throws 
     */
    List<TabSysUser> listGicUser(@Param("enterpriseId")Integer enterpriseId, @Param("isGic") Integer isGic);
}