package com.gic.auth.service.outer.impl;

import com.gic.api.base.commons.ServiceResponse;
import com.gic.auth.dto.AuthCodeDTO;
import com.gic.auth.entity.TabSysAuthCode;
import com.gic.auth.service.AuthCodeApiService;
import com.gic.auth.service.AuthCodeService;
import com.gic.commons.util.EntityUtil;
import com.gic.enterprise.constants.Constants;
import com.gic.enterprise.error.ErrorCode;
import com.gic.enterprise.response.EnterpriseServiceResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
/**
 * 
 * @ClassName: AuthCodeApiServiceImpl
 * @Description:  
 * @author zhiwj
 * @date 2020-09-10 9:36
 */
@Service("authCodeApiService")
public class AuthCodeApiServiceImpl implements AuthCodeApiService {
    @Autowired
    private AuthCodeService authCodeService;
    @Override
    public ServiceResponse<Integer> saveAuth(AuthCodeDTO authCodeDTO) {
        TabSysAuthCode sysAuthCode = EntityUtil.changeEntityByJSON(TabSysAuthCode.class, authCodeDTO);
        sysAuthCode.setCreateTime(new Date());
        sysAuthCode.setUpdateTime(new Date());
        sysAuthCode.setStatus(Constants.NORMAL_STATUS);
        this.authCodeService.saveAuthCode(sysAuthCode);
        return ServiceResponse.success(sysAuthCode.getAuthCodeId());
    }

    @Override
    public ServiceResponse<Integer> expireAuthCode(Integer authCodeId) {
        int result = this.authCodeService.expireAuthCode(authCodeId);
        return ServiceResponse.success(result);
    }

    @Override
    public ServiceResponse<AuthCodeDTO> getAuthCode(Integer enterpriseId, Integer relationId) {
        TabSysAuthCode sysAuthCode = this.authCodeService.getAuthCode(enterpriseId, relationId);
        return ServiceResponse.success(EntityUtil.changeEntityByJSON(AuthCodeDTO.class, sysAuthCode));
    }

    @Override
    public ServiceResponse<AuthCodeDTO> getAuthCode(Integer authCodeId) {
        TabSysAuthCode sysAuthCode = this.authCodeService.getAuthCode(authCodeId);
        return ServiceResponse.success(EntityUtil.changeEntityByJSON(AuthCodeDTO.class, sysAuthCode));
    }

    @Override
    public ServiceResponse validateAuthCode(Integer authCodeId, String authCode) {
        TabSysAuthCode sysAuthCode = this.authCodeService.getAuthCode(authCodeId);
        if(sysAuthCode != null){
            if(sysAuthCode.getStatus() == 0){
                return EnterpriseServiceResponse.failure(ErrorCode.AUTHCODE_USED);
            }
            if(sysAuthCode.getExpirationTime().before(new Date())){
                return EnterpriseServiceResponse.failure(ErrorCode.AUTHCODE_EXPIRE);
            }
            if(!sysAuthCode.getAuthCode().equals(authCode)){
                return EnterpriseServiceResponse.failure(ErrorCode.AUTHCODE_MISTAKE);
            }
        }else {
            EnterpriseServiceResponse.failure(ErrorCode.AUTHCODE_ERR);
        }
        return ServiceResponse.success();
    }
}
